@@ -316,5 +316,4 @@ class Enough(object):
             self.libvirt.backup_prune(OpenStack(self.config_dir, **self.args))
 
     def libvirt_install(self):
-        return libvirt_install(self.config_dir, self.share_dir,
-                               self.args['domain'], self.args['host'])
+        return libvirt_install(self.config_dir, self.share_dir, **self.args)
