@@ -1,6 +1,7 @@
 import ast
 import base64
 import datetime
+import io
 import json
 import logging
 import os
@@ -135,9 +136,26 @@ class Stack(OpenStackBase):
         server = self.definition['name']
         network = self.definition.get('internal_network', OpenStackBase.INTERNAL_NETWORK)
         o = OpenStack(self.config_dir, **self.args)
-        if o.server_connected_to_network(server, network):
-            return
-        self.o.server.add.network(server, network)
+        if not o.server_connected_to_network(server, network):
+            self.o.server.add.network(server, network)
+        if self.definition['openvpn_is_server']:
+            err = io.StringIO()
+            try:
+                self.o.extension.show('-c', 'id', '-f', 'value',
+                                      'port-security', _err=err)
+                port_security_enabled = True
+            except sh.ErrorReturnCode_1:
+                err.seek(0)
+                if 'No Extension found for port-security' == err.read().strip():
+                    port_security_enabled = False
+                else:
+                    raise
+            if port_security_enabled:
+                port = self.o.port.list('--server', server, '--network',
+                                        network, '-f', 'value', '-c', 'ID')
+                port = port.strip()
+                self.o.port.set('--no-allowed-address', '--allowed-address',
+                                'ip-address=0.0.0.0/0', port)
 
     def internal_only(self):
         return self.definition.get('network_internal_only', False)
@@ -206,6 +224,7 @@ class Heat(OpenStackBase):
             'internal_network': OpenStackBase.INTERNAL_NETWORK,
             'internal_network_cidr': hv.get('openstack_internal_network_cidr',
                                             OpenStackBase.INTERNAL_NETWORK_CIDR),
+            'openvpn_is_server': hv.get('openvpn_is_server', False),
         }
         if 'openstack_volumes' in hv:
             definition['volumes'] = hv['openstack_volumes']
