@@ -1,6 +1,7 @@
 #!/bin/bash
 
-source /usr/lib/backup/openrc.sh
+export OS_CLIENT_CONFIG_FILE=/usr/lib/backup/clouds.yml
+export OS_CLOUD=production
 
 function backup() {
     local host=$1
