@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'chat-host')
-        assert r['attrs']['name'] == 'chat-host'
+        assert 'chat-host' in self.get_hosts(host='chat-host')
 
     def test_service(self, host):
         assert self.is_service_ok('chat-host!Chat')
