@@ -12,7 +12,7 @@ def test_proxy(host):
 def test_named_proxy(host):
     with host.sudo():
         host.run("apt-get install -y curl")
-    for name in ('name1', 'name2'):
+    for name in ('name1', 'name2', 'name3'):
         r = host.run(f"curl -s -m 5 http://{name}.$(hostname -d)/index.html")
         assert r.rc == 0
         assert 'NAMEDBACKEND' in r.stdout
