@@ -8,9 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'cloud-host')
-        assert r['attrs']['name'] == 'cloud-host'
+        assert 'cloud-host' in self.get_hosts(host='cloud-host')
 
     def test_service(self, host):
         assert self.is_service_ok('cloud-host!cloud-host')
-        assert self.is_service_ok('cloud-host!cloud-host over Tor')
