@@ -6,7 +6,7 @@ def test_discourse(host):
     set -xe
     sudo apt-get install -y curl
     curl --silent https://forum.$(hostname -d) | \
-       grep --quiet 'Congratulations, you installed Discourse!'
+       grep --quiet 'Welcome to Discourse'
     """)
     print(cmd.stdout)
     print(cmd.stderr)
