@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'website-host')
-        assert r['attrs']['name'] == 'website-host'
+        assert 'website-host' in self.get_hosts(host='website-host')
 
     def test_service(self):
         assert self.is_service_ok('website-host!Pad')
