@@ -397,7 +397,7 @@ def test_image_create_from_volume(openstack_name, dot_openstack):
     assert o.image_status(openstack_name) == 'active'
     li = [
         i.strip() for i in o.o.image.list(
-            '--shared', '--format=value', '-c', 'Name', _iter=True)
+            '--private', '--format=value', '-c', 'Name', _iter=True)
     ]
     assert li == [openstack_name]
     o.o.image.delete(openstack_name)
